/* SPDX-License-Identifier: LGPL-2.1-only OR BSD-3-Clause */
/******************************************************************************
 *
 * This file is provided under a dual license.  When you use or
 * distribute this software, you may choose to be licensed under
 * version 2.1 of the GNU Lesser General Public License
 * ("LGPLv2.1 License") or BSD License.
 *
 * LGPLv2.1 License
 *
 * Copyright(C) 2019 MediaTek Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of version 2.1 of the GNU Lesser General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html for more
 * details.
 *
 * BSD LICENSE
 *
 * Copyright(C) 2019 MediaTek Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  * Neither the name of the copyright holder nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *****************************************************************************/

/*-----------------------------------------------------------------------------
 * $RCSfile: x_time_msrt.h,v $
 * $Revision: #1 $
 * $Date: 2015/11/10 $
 * $Author: dtvbm11 $
 * $CCRevision: /main/DTV_X_ATSC/3 $
 * $SWAuthor: Iolo Tsai $
 * $MD5HEX: 1dac4c9e9e39d373009607399c7215fb $
 *
 * Description: 
 *---------------------------------------------------------------------------*/

#ifndef _X_TIME_MSRT_H_
#define _X_TIME_MSRT_H_
/*-----------------------------------------------------------------------------
                    include files
-----------------------------------------------------------------------------*/
#ifdef LINUX_TURNKEY_SOLUTION
#include "x_common.h"
#include "u_time_msrt.h"
#else
#include "x_common.h"
#include "u_time_msrt.h"
#endif
/*-----------------------------------------------------------------------------
                    macros, defines, typedefs, enums
-----------------------------------------------------------------------------*/
typedef struct
{
	CHAR							  s_name[TMS_NAME_MAX_LENGTH+1];
	UINT16							  ui2_level;
	CHAR							  s_comment[TMS_COMMENT_MAX_LENGTH+1];
	INT32							  i4_ret;
	UINT32							  ui4_flag;
	UINT32							  ui4_tms;
	UINT16							  ui2_common_level;
}PARAM_TMS;
	
#ifdef TIME_MEASUREMENT

#define TIME_MSRT_SPOT( _tms_mdl_level, _name)
#define TIME_MSRT_DIFF( _tms_mdl_level, _name)
#define TIME_MSRT_BEGIN( _tms_mdl_level, _name)
#define TIME_MSRT_END( _tms_mdl_level, _name)


#ifndef __KERNEL__

#define TIME_MSRT_SPOT_EX( _tms_mdl_level, _flag, _name, _comment)            \
{                                                                             \
    extern UINT16 time_msrt_get_level( UINT16 );                              \
    extern UINT32 time_msrt_get_flag( VOID );                                 \
    UINT32 ui4_flag = time_msrt_get_flag();                                   \
    if (ui4_flag & _flag)                                                     \
    {                                                                         \
        UINT16 ui2_final_lvl = time_msrt_get_level( _tms_mdl_level );         \
        if ( ui2_final_lvl != TMS_LEVEL_NONE )                                \
        {                                                                     \
            x_time_msrt_spot( _name, ui2_final_lvl, _comment );               \
        }                                                                     \
    }                                                                         \
}

#define TIME_MSRT_DIFF_EX( _tms_mdl_level, _flag, _name, _comment)            \
{                                                                             \
    extern UINT16 time_msrt_get_level( UINT16 );                              \
    extern UINT32 time_msrt_get_flag( VOID );                                 \
    UINT32 ui4_flag = time_msrt_get_flag();                                   \
    if (ui4_flag & _flag)                                                     \
    {                                                                         \
        UINT16 ui2_final_lvl = time_msrt_get_level( _tms_mdl_level );         \
        if ( ui2_final_lvl != TMS_LEVEL_NONE )                                \
        {                                                                     \
            x_time_msrt_diff( _name, ui2_final_lvl, _comment );               \
        }                                                                     \
    }                                                                         \
}

#define TIME_MSRT_BEGIN_EX( _tms_mdl_level, _flag, _name, _comment)           \
{                                                                             \
    extern UINT16 time_msrt_get_level( UINT16 );                              \
    extern UINT32 time_msrt_get_flag( VOID );                                 \
    UINT32 ui4_flag = time_msrt_get_flag();                                   \
    if (ui4_flag & _flag)                                                     \
    {                                                                         \
        UINT16 ui2_final_lvl = time_msrt_get_level( _tms_mdl_level );         \
        if ( ui2_final_lvl != TMS_LEVEL_NONE )                                \
        {                                                                     \
            x_time_msrt_begin( _name, ui2_final_lvl, _comment );              \
        }                                                                     \
    }                                                                         \
}

#define TIME_MSRT_END_EX( _tms_mdl_level, _flag, _name, _comment)             \
{                                                                             \
    extern UINT16 time_msrt_get_level( UINT16 );                              \
    extern UINT32 time_msrt_get_flag( VOID );                                 \
    UINT32 ui4_flag = time_msrt_get_flag();                                   \
    if (ui4_flag & _flag)                                                     \
    {                                                                         \
        UINT16 ui2_final_lvl = time_msrt_get_level( _tms_mdl_level );         \
        if ( ui2_final_lvl != TMS_LEVEL_NONE )                                \
        {                                                                     \
            x_time_msrt_end( _name, ui2_final_lvl, _comment );                \
        }                                                                     \
        if((TMS_FLAG_POWER_OFF | TMS_FLAG_NONE) == ui4_flag)                  \
        {                                                                     \
            x_time_msrt_dump_detail(NULL);                                           \
        }                                                                     \
    }                                                                         \
}
#else

#define TIME_MSRT_SPOT_EX( _tms_mdl_level, _flag, _name, _comment)            \
{                                                                             \
    extern UINT16 _time_msrt_get_level( UINT16 );                              \
    extern UINT32 _time_msrt_get_flag( VOID );                                 \
    UINT32 ui4_flag = _time_msrt_get_flag();                                   \
    if (ui4_flag & _flag)                                                     \
    {                                                                         \
        UINT16 ui2_final_lvl = _time_msrt_get_level( _tms_mdl_level );         \
        if ( ui2_final_lvl != TMS_LEVEL_NONE )                                \
        {                                                                     \
            _time_msrt_spot( _name, ui2_final_lvl, _comment );               \
        }                                                                     \
    }                                                                         \
}

#define TIME_MSRT_DIFF_EX( _tms_mdl_level, _flag, _name, _comment)            \
{                                                                             \
    extern UINT16 _time_msrt_get_level( UINT16 );                              \
    extern UINT32 _time_msrt_get_flag( VOID );                                 \
    UINT32 ui4_flag = _time_msrt_get_flag();                                   \
    if (ui4_flag & _flag)                                                     \
    {                                                                         \
        UINT16 ui2_final_lvl = _time_msrt_get_level( _tms_mdl_level );         \
        if ( ui2_final_lvl != TMS_LEVEL_NONE )                                \
        {                                                                     \
            _time_msrt_diff( _name, ui2_final_lvl, _comment );               \
        }                                                                     \
    }                                                                         \
}

#define TIME_MSRT_BEGIN_EX( _tms_mdl_level, _flag, _name, _comment)           \
{                                                                             \
    extern UINT16 _time_msrt_get_level( UINT16 );                              \
    extern UINT32 _time_msrt_get_flag( VOID );                                 \
    UINT32 ui4_flag = _time_msrt_get_flag();                                   \
    if (ui4_flag & _flag)                                                     \
    {                                                                         \
        UINT16 ui2_final_lvl = _time_msrt_get_level( _tms_mdl_level );         \
        if ( ui2_final_lvl != TMS_LEVEL_NONE )                                \
        {                                                                     \
            _time_msrt_begin( _name, ui2_final_lvl, _comment );              \
        }                                                                     \
    }                                                                         \
}

#define TIME_MSRT_END_EX( _tms_mdl_level, _flag, _name, _comment)             \
{                                                                             \
    extern UINT16 _time_msrt_get_level( UINT16 );                              \
    extern UINT32 _time_msrt_get_flag( VOID );                                 \
    UINT32 ui4_flag = _time_msrt_get_flag();                                   \
    if (ui4_flag & _flag)                                                     \
    {                                                                         \
        UINT16 ui2_final_lvl = _time_msrt_get_level( _tms_mdl_level );         \
        if ( ui2_final_lvl != TMS_LEVEL_NONE )                                \
        {                                                                     \
            _time_msrt_end( _name, ui2_final_lvl, _comment );                \
        }                                                                     \
        if((TMS_FLAG_POWER_OFF | TMS_FLAG_NONE) == ui4_flag)                  \
        {                                                                     \
            _time_msrt_dump_detail(NULL);                                           \
        }                                                                     \
    }                                                                         \
}

#endif

#else
#define TIME_MSRT_SPOT( _tms_mdl_level, _name)
#define TIME_MSRT_DIFF( _tms_mdl_level, _name)
#define TIME_MSRT_BEGIN( _tms_mdl_level, _name)
#define TIME_MSRT_END( _tms_mdl_level, _name)
#define TIME_MSRT_SPOT_EX( _tms_mdl_level, _flag, _name, _comment)
#define TIME_MSRT_DIFF_EX( _tms_mdl_level, _flag, _name, _comment)
#define TIME_MSRT_BEGIN_EX( _tms_mdl_level, _flag, _name, _comment)
#define TIME_MSRT_END_EX( _tms_mdl_level, _flag, _name, _comment)
#endif /* TIME_MEASUREMENT */


/*-----------------------------------------------------------------------------
                    functions declarations
-----------------------------------------------------------------------------*/
#ifndef __KERNEL__ 
extern INT32 x_time_msrt_spot( 
    const CHAR*           s_name,
    UINT16                ui2_tms_lvl,
    const CHAR*           s_comment );

extern INT32 x_time_msrt_diff(
    const CHAR*           s_name,
    UINT16                ui2_tms_lvl,
    const CHAR*           s_comment );

extern INT32 x_time_msrt_begin( 
    const CHAR*           s_name,
    UINT16                ui2_tms_lvl,
    const CHAR*           s_comment );

extern INT32 x_time_msrt_end( 
    const CHAR*           s_name,
    UINT16                ui2_tms_lvl,
    const CHAR*           s_comment );

extern VOID x_time_msrt_dump( const CHAR* s_name );

extern VOID x_time_msrt_dump_detail( const CHAR* s_name );

extern VOID x_time_msrt_clean( const CHAR* s_name );

#else

extern INT32 _time_msrt_init( SIZE_T z_max_num_records );

extern INT32 _time_msrt_spot(
    const CHAR*           s_name,
    UINT16                ui2_tms_lvl,
    const CHAR*           s_comment );

extern INT32 _time_msrt_diff(
    const CHAR*           s_name,
    UINT16                ui2_tms_lvl,
    const CHAR*           s_comment );

extern INT32 _time_msrt_begin(
    const CHAR*           s_name,
    UINT16                ui2_tms_lvl,
    const CHAR*           s_comment );

extern INT32 _time_msrt_end(
    const CHAR*           s_name,
    UINT16                ui2_tms_lvl,
    const CHAR*           s_comment );

extern VOID _time_msrt_dump( const CHAR* s_name );

extern VOID _time_msrt_dump_detail( const CHAR* s_name );

extern VOID _time_msrt_clean( const CHAR* s_name );

/*-----------------------------------------------------------------------------
                    functions declaraions
 ----------------------------------------------------------------------------*/
extern UINT16 _time_msrt_get_level( UINT16 ui2_tms_mdl_level );
extern UINT32 _time_msrt_get_flag( VOID );
extern void _time_msrt_set_flag(UINT32 flag);
extern void _time_msrt_set_tms_sel(UINT32 e_tms);
extern UINT16 _time_msrt_get_common_tms_level (VOID);
extern void _time_msrt_set_common_tms_level (UINT16 ui2_tms_level);

#endif /* _X_TIME_MSRT_H_ */
#endif
